Documentation
¶
Index ¶
- type BlueprintManager
- func (b *BlueprintManager) DeleteBlueprint(id uint64) errors.Error
- func (b *BlueprintManager) GetBlueprintsByConnection(plugin string, connectionId uint64) ([]*models.Blueprint, errors.Error)
- func (b *BlueprintManager) GetBlueprintsByScopes(connectionId uint64, pluginName string, scopeIds ...string) (map[string][]*models.Blueprint, errors.Error)
- func (b *BlueprintManager) GetDbBlueprint(blueprintId uint64) (*models.Blueprint, errors.Error)
- func (b *BlueprintManager) GetDbBlueprintByProjectName(projectName string) (*models.Blueprint, errors.Error)
- func (b *BlueprintManager) GetDbBlueprints(query *GetBlueprintQuery) ([]*models.Blueprint, int64, errors.Error)
- func (b *BlueprintManager) SaveDbBlueprint(blueprint *models.Blueprint) errors.Error
- type BlueprintProjectPairs
- type GetBlueprintQuery
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlueprintManager ¶
type BlueprintManager struct {
// contains filtered or unexported fields
}
func NewBlueprintManager ¶
func NewBlueprintManager(db dal.Dal) *BlueprintManager
func (*BlueprintManager) DeleteBlueprint ¶
func (b *BlueprintManager) DeleteBlueprint(id uint64) errors.Error
DeleteBlueprint deletes a blueprint by its id
func (*BlueprintManager) GetBlueprintsByConnection ¶
func (b *BlueprintManager) GetBlueprintsByConnection(plugin string, connectionId uint64) ([]*models.Blueprint, errors.Error)
GetBlueprintsByScopes returns all blueprints that have these scopeIds and this connection Id
func (*BlueprintManager) GetBlueprintsByScopes ¶
func (b *BlueprintManager) GetBlueprintsByScopes(connectionId uint64, pluginName string, scopeIds ...string) (map[string][]*models.Blueprint, errors.Error)
GetBlueprintsByScopes returns all blueprints that have these scopeIds and this connection Id
func (*BlueprintManager) GetDbBlueprint ¶
GetDbBlueprint returns the detail of a given Blueprint ID
func (*BlueprintManager) GetDbBlueprintByProjectName ¶
func (b *BlueprintManager) GetDbBlueprintByProjectName(projectName string) (*models.Blueprint, errors.Error)
GetDbBlueprintByProjectName returns the detail of a given projectName
func (*BlueprintManager) GetDbBlueprints ¶
func (b *BlueprintManager) GetDbBlueprints(query *GetBlueprintQuery) ([]*models.Blueprint, int64, errors.Error)
GetDbBlueprints returns a paginated list of Blueprints based on `query`
func (*BlueprintManager) SaveDbBlueprint ¶
func (b *BlueprintManager) SaveDbBlueprint(blueprint *models.Blueprint) errors.Error
SaveDbBlueprint accepts a Blueprint instance and upsert it to database
type BlueprintProjectPairs ¶
type BlueprintProjectPairs struct {
Projects []string `json:"projects"`
Blueprints []string `json:"blueprints"`
}
func NewBlueprintProjectPairs ¶
func NewBlueprintProjectPairs(bps []*models.Blueprint) *BlueprintProjectPairs
Click to show internal directories.
Click to hide internal directories.