Documentation
¶
Index ¶
- type ApiBambooOperations
- type ApiResourcesResponse
- type BambooConn
- type BambooConnection
- type BambooDeployBuild
- type BambooDeployEnvironment
- type BambooJob
- type BambooJobBuild
- type BambooPlan
- type BambooPlanBuild
- type BambooPlanBuildVcsRevision
- type BambooProject
- type BambooResponse
- type BambooTransformationRule
- type BaseConnection
- type BasicAuth
- type Model
- type RestConnection
- type TestConnectionRequest
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiBambooOperations ¶
type ApiBambooOperations struct {
CanView bool `json:"canView"`
CanEdit bool `json:"canEdit"`
CanDelete bool `json:"canDelete"`
AllowedToExecute bool `json:"allowedToExecute"`
CanExecute bool `json:"canExecute"`
AllowedToCreateVersion bool `json:"allowedToCreateVersion"`
AllowedToSetVersionStatus bool `json:"allowedToSetVersionStatus"`
}
type ApiResourcesResponse ¶
type ApiResourcesResponse struct {
Resources string `json:"resources" xml:"resources"`
}
Using User because it requires authentication.
type BambooConn ¶
type BambooConn struct {
RestConnection `mapstructure:",squash"`
//TODO you may need to use helper.BasicAuth instead of helper.AccessToken
BasicAuth `mapstructure:",squash"`
}
type BambooConnection ¶
type BambooConnection struct {
BaseConnection `mapstructure:",squash"`
BambooConn `mapstructure:",squash"`
}
TODO Please modify the following code to fit your needs This object conforms to what the frontend currently sends.
func (BambooConnection) TableName ¶
func (BambooConnection) TableName() string
type BambooDeployBuild ¶
type BambooDeployBuild struct {
ConnectionId uint64 `json:"connection_id" gorm:"primaryKey"`
DeployBuildId uint64 `json:"deploy_build_id" gorm:"primaryKey"`
DeploymentVersionName string `json:"deploymentVersionName"`
DeploymentState string `json:"deploymentState"`
LifeCycleState string `json:"lifeCycleState"`
StartedDate *time.Time `json:"startedDate"`
QueuedDate *time.Time `json:"queuedDate"`
ExecutedDate *time.Time `json:"executedDate"`
FinishedDate *time.Time `json:"finishedDate"`
ReasonSummary string `json:"reasonSummary"`
ProjectKey string `json:"project_key" gorm:"index"`
PlanKey string `json:"plan_key" gorm:"index"`
ApiBambooOperations
archived.NoPKModel
}
func (BambooDeployBuild) TableName ¶
func (BambooDeployBuild) TableName() string
type BambooDeployEnvironment ¶
type BambooDeployEnvironment struct {
ConnectionId uint64 `json:"connection_id" gorm:"primaryKey"`
EnvId uint64 `json:"env_id" gorm:"primaryKey"`
EnvKey string `json:"key" gorm:"index;type:varchar(255)"`
Name string `json:"name" gorm:"index;type:varchar(255)"`
PlanKey string `json:"plan_key" gorm:"index;type:varchar(255)"`
ProjectKey string `json:"project_key" gorm:"index"`
Description string `json:"description"`
DeploymentProjectId uint64 `json:"deploymentProjectId"`
Position uint64 `json:"position"`
ConfigurationState string `json:"configurationState"`
ApiBambooOperations
archived.NoPKModel
}
func (BambooDeployEnvironment) TableName ¶
func (BambooDeployEnvironment) TableName() string
type BambooJob ¶
type BambooJob struct {
ConnectionId uint64 `gorm:"primaryKey"`
JobKey string `gorm:"primaryKey"`
Id string
Name string `json:"name"`
PlanKey string `json:"planKey"`
PlanName string `json:"planName"`
ProjectKey string `gorm:"index"`
ProjectName string `json:"projectName"`
Description string `json:"description"`
BranchName string `json:"branchName"`
StageName string `json:"stageName"`
Type string `json:"type"`
archived.NoPKModel
}
type BambooJobBuild ¶
type BambooJobBuild struct {
ConnectionId uint64 `gorm:"primaryKey"`
JobBuildKey string `gorm:"primaryKey"`
PlanBuildKey string `gorm:"index"`
Expand string `json:"expand"`
Number int `json:"number"`
BuildNumber int `json:"buildNumber"`
JobName string `gorm:"index"`
JobKey string `gorm:"index"`
PlanName string `gorm:"index"`
PlanKey string `gorm:"index"`
ProjectName string `gorm:"index"`
ProjectKey string `gorm:"index"`
BuildResultKey string `json:"buildResultKey"`
LifeCycleState string `json:"lifeCycleState"`
BuildStartedTime *time.Time `json:"buildStartedTime"`
PrettyBuildStartedTime string `json:"prettyBuildStartedTime"`
BuildCompletedTime *time.Time `json:"buildCompletedTime"`
BuildCompletedDate *time.Time `json:"buildCompletedDate"`
PrettyBuildCompletedTime string `json:"prettyBuildCompletedTime"`
BuildDurationInSeconds int `json:"buildDurationInSeconds"`
BuildDuration int `json:"buildDuration"`
BuildDurationDescription string `json:"buildDurationDescription"`
BuildRelativeTime string `json:"buildRelativeTime"`
VcsRevisionKey string `json:"vcsRevisionKey"`
BuildTestSummary string `json:"buildTestSummary"`
SuccessfulTestCount int `json:"successfulTestCount"`
FailedTestCount int `json:"failedTestCount"`
QuarantinedTestCount int `json:"quarantinedTestCount"`
SkippedTestCount int `json:"skippedTestCount"`
Continuable bool `json:"continuable"`
OnceOff bool `json:"onceOff"`
Restartable bool `json:"restartable"`
NotRunYet bool `json:"notRunYet"`
Finished bool `json:"finished"`
Successful bool `json:"successful"`
BuildReason string `json:"buildReason"`
ReasonSummary string `json:"reasonSummary"`
State string `json:"state"`
BuildState string `json:"buildState"`
JobResultKey string
archived.NoPKModel
}
func (BambooJobBuild) TableName ¶
func (BambooJobBuild) TableName() string
type BambooPlan ¶
type BambooPlan struct {
ConnectionId uint64 `gorm:"primaryKey"`
PlanKey string `json:"planKey" gorm:"primaryKey"`
Name string `json:"name"`
Expand string `json:"expand"`
ProjectKey string `json:"projectKey" gorm:"index"`
ProjectName string `json:"projectName"`
Description string `json:"description"`
ShortName string `json:"shortName"`
BuildName string `json:"buildName"`
ShortKey string `json:"shortKey"`
Type string `json:"type"`
Enabled bool `json:"enabled"`
Href string `json:"href"`
Rel string `json:"rel"`
IsFavourite bool `json:"isFavourite"`
IsActive bool `json:"isActive"`
IsBuilding bool `json:"isBuilding"`
AverageBuildTimeInSeconds float64 `json:"averageBuildTimeInSeconds"`
archived.NoPKModel
}
func (*BambooPlan) TableName ¶
func (b *BambooPlan) TableName() string
type BambooPlanBuild ¶
type BambooPlanBuild struct {
ConnectionId uint64 `gorm:"primaryKey"`
PlanBuildKey string `gorm:"primaryKey"`
Expand string `json:"expand"`
Number int `json:"number"`
BuildNumber int `json:"buildNumber"`
PlanName string `json:"planName"`
PlanKey string
ProjectName string `json:"projectName"`
ProjectKey string
BuildResultKey string `json:"buildResultKey"`
LifeCycleState string `json:"lifeCycleState"`
BuildStartedTime *time.Time `json:"buildStartedTime"`
PrettyBuildStartedTime string `json:"prettyBuildStartedTime"`
BuildCompletedTime *time.Time `json:"buildCompletedTime"`
BuildCompletedDate *time.Time `json:"buildCompletedDate"`
PrettyBuildCompletedTime string `json:"prettyBuildCompletedTime"`
BuildDurationInSeconds int `json:"buildDurationInSeconds"`
BuildDuration int `json:"buildDuration"`
BuildDurationDescription string `json:"buildDurationDescription"`
BuildRelativeTime string `json:"buildRelativeTime"`
VcsRevisionKey string `json:"vcsRevisionKey"`
BuildTestSummary string `json:"buildTestSummary"`
SuccessfulTestCount int `json:"successfulTestCount"`
FailedTestCount int `json:"failedTestCount"`
QuarantinedTestCount int `json:"quarantinedTestCount"`
SkippedTestCount int `json:"skippedTestCount"`
Continuable bool `json:"continuable"`
OnceOff bool `json:"onceOff"`
Restartable bool `json:"restartable"`
NotRunYet bool `json:"notRunYet"`
Finished bool `json:"finished"`
Successful bool `json:"successful"`
BuildReason string `json:"buildReason"`
ReasonSummary string `json:"reasonSummary"`
State string `json:"state"`
BuildState string `json:"buildState"`
PlanResultKey string
archived.NoPKModel
}
func (BambooPlanBuild) TableName ¶
func (BambooPlanBuild) TableName() string
type BambooPlanBuildVcsRevision ¶
type BambooPlanBuildVcsRevision struct {
ConnectionId uint64 `gorm:"primaryKey"`
PlanBuildKey string `gorm:"primaryKey"`
RepositoryId int
RepositoryName string `json:"repositoryName"`
VcsRevisionKey string `gorm:"primaryKey"`
archived.NoPKModel
}
func (BambooPlanBuildVcsRevision) TableName ¶
func (BambooPlanBuildVcsRevision) TableName() string
type BambooProject ¶
type BambooProject struct {
ConnectionId uint64 `gorm:"primaryKey"`
ProjectKey string `gorm:"primaryKey;type:varchar(100)"`
Expand string `json:"expand"`
Name string `gorm:"index;type:varchar(100)"`
Description string `json:"description"`
Href string `json:"link"`
Rel string `gorm:"type:varchar(100)"`
TransformationRuleId uint64 `json:"transformationRuleId,omitempty" mapstructure:"transformationRuleId"`
archived.NoPKModel
}
func (BambooProject) TableName ¶
func (BambooProject) TableName() string
type BambooResponse ¶
type BambooResponse struct {
Name string `json:"name"`
ID int `json:"id"`
BambooConnection
}
This object conforms to what the frontend currently expects.
type BambooTransformationRule ¶
type BambooTransformationRule struct {
archived.Model
Name string `gorm:"type:varchar(255);index:idx_name_gitlab,unique" validate:"required" mapstructure:"name" json:"name"`
// should be {realRepoName: [bamboo_repoId]}
RepoMap datatypes.JSONMap
DeploymentPattern string `mapstructure:"deploymentPattern,omitempty" json:"deploymentPattern" gorm:"type:varchar(255)"`
ProductionPattern string `mapstructure:"productionPattern,omitempty" json:"productionPattern" gorm:"type:varchar(255)"`
}
func (BambooTransformationRule) TableName ¶
func (BambooTransformationRule) TableName() string
type BaseConnection ¶
type RestConnection ¶
type RestConnection struct {
Endpoint string `mapstructure:"endpoint" validate:"required" json:"endpoint"`
Proxy string `mapstructure:"proxy" json:"proxy"`
RateLimitPerHour int `comment:"api request rate limit per hour" json:"rateLimitPerHour"`
}
RestConnection implements the ApiConnection interface
type TestConnectionRequest ¶
Click to show internal directories.
Click to hide internal directories.