Documentation
¶
Index ¶
Constants ¶
const ( TapExecutable = "tap-pagerduty" StreamPropertiesFile = "pagerduty.json" IncidentStream = "incidents" )
The consts that this plugin needs
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiUserResponse ¶
Using User because it requires authentication.
type Assignment ¶
type Assignment struct {
common.NoPKModel
ConnectionId uint64
UserId string `gorm:"primaryKey"`
IncidentNumber int `gorm:"primaryKey"`
AssignedAt time.Time
}
func (Assignment) TableName ¶
func (Assignment) TableName() string
type Incident ¶
type IncidentStatus ¶
type IncidentStatus string
const ( IncidentStatusAcknowledged IncidentStatus = "acknowledged" IncidentStatusTriggered IncidentStatus = "triggered" IncidentStatusResolved IncidentStatus = "resolved" )
type IncidentUrgency ¶
type IncidentUrgency string
type PagerDutyAccessToken ¶
type PagerDutyAccessToken helper.AccessToken
AccessToken implements HTTP Token Authentication with Access Token
func (*PagerDutyAccessToken) SetupAuthentication ¶
func (at *PagerDutyAccessToken) SetupAuthentication(request *http.Request) errors.Error
SetupAuthentication sets up the request headers for authentication
type PagerDutyConn ¶
type PagerDutyConn struct {
helper.RestConnection `mapstructure:",squash"`
PagerDutyAccessToken `mapstructure:",squash"`
}
PagerDutyConn holds the essential information to connect to the PagerDuty API
type PagerDutyConnection ¶
type PagerDutyConnection struct {
helper.BaseConnection `mapstructure:",squash"`
PagerDutyConn `mapstructure:",squash"`
}
PagerDutyConnection holds GitlabConn plus ID/Name for database storage
func (PagerDutyConnection) TableName ¶
func (PagerDutyConnection) TableName() string
type PagerDutyParams ¶
type PagerDutyResponse ¶
type PagerDutyResponse struct {
Name string `json:"name"`
ID int `json:"id"`
PagerDutyConnection
}
This object conforms to what the frontend currently expects.
type PagerdutyScopeConfig ¶
type PagerdutyScopeConfig struct {
common.ScopeConfig `mapstructure:",squash" json:",inline" gorm:"embedded"`
Name string `mapstructure:"name" json:"name" gorm:"type:varchar(255);index:idx_name_github,unique" validate:"required"`
ConnectionId uint64
}
type Service ¶
type Service struct {
common.NoPKModel
ConnectionId uint64 `json:"connection_id" mapstructure:"connectionId,omitempty" gorm:"primaryKey" `
Id string `json:"id" mapstructure:"id" gorm:"primaryKey;autoIncrement:false" `
Url string `json:"url" mapstructure:"url"`
Name string `json:"name" mapstructure:"name"`
}
func (Service) ScopeParams ¶
func (s Service) ScopeParams() interface{}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.