Documentation
¶
Index ¶
- type ApiAccessTokenRequest
- type ApiAccessTokenResponse
- type ApiUserResponse
- type Hours
- type PM
- type Whitelist
- type ZentaoAccount
- type ZentaoApiParams
- type ZentaoBug
- type ZentaoBugCommit
- type ZentaoBugCommitsRes
- type ZentaoBugRepoCommit
- type ZentaoBugRepoCommitsRes
- type ZentaoBugRes
- type ZentaoChangelog
- type ZentaoChangelogCom
- type ZentaoChangelogDetail
- type ZentaoConn
- type ZentaoConnection
- type ZentaoDepartment
- type ZentaoExecution
- type ZentaoExecutionRes
- type ZentaoProduct
- type ZentaoProductRes
- type ZentaoProject
- type ZentaoRemoteDbAction
- type ZentaoRemoteDbActionHistory
- type ZentaoRemoteDbHistory
- type ZentaoRemoteDbHistoryBase
- type ZentaoResponse
- type ZentaoScopeConfig
- type ZentaoStory
- type ZentaoStoryCommit
- type ZentaoStoryCommitsRes
- type ZentaoStoryRepoCommit
- type ZentaoStoryRepoCommitsRes
- type ZentaoStoryRes
- type ZentaoTask
- type ZentaoTaskCommit
- type ZentaoTaskCommitsRes
- type ZentaoTaskRepoCommit
- type ZentaoTaskRepoCommitsRes
- type ZentaoTaskRes
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiAccessTokenRequest ¶
type ApiAccessTokenResponse ¶
type ApiAccessTokenResponse struct {
Token string `json:"token"`
}
type ApiUserResponse ¶
Using User because it requires authentication.
type Hours ¶
type Hours struct {
HoursTotalEstimate float64 `json:"totalEstimate" mapstructure:"totalEstimate"`
HoursTotalConsumed float64 `json:"totalConsumed" mapstructure:"totalConsumed"`
HoursTotalLeft float64 `json:"totalLeft" mapstructure:"totalLeft"`
HoursProgress float64 `json:"progress" mapstructure:"progress"`
HoursTotalReal float64 `json:"totalReal" mapstructure:"totalReal"`
}
type ZentaoAccount ¶
type ZentaoAccount struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int64 `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false" `
Account string `json:"account" gorm:"type:varchar(100);index"`
Avatar string `json:"avatar" gorm:"type:varchar(255)"`
Realname string `json:"realname" gorm:"type:varchar(100);index"`
Role string `json:"role" gorm:"type:varchar(100);index"`
Dept int64 `json:"dept" gorm:"type:BIGINT NOT NULL;index"`
}
func (ZentaoAccount) TableName ¶
func (ZentaoAccount) TableName() string
type ZentaoApiParams ¶
type ZentaoBug ¶
type ZentaoBug struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int64 `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
Project int64 `json:"project"`
Product int64 `json:"product"`
Injection int `json:"injection"`
Identify int `json:"identify"`
Branch int `json:"branch"`
Module int `json:"module"`
Execution int64 `json:"execution"`
Plan int `json:"plan"`
Story int64 `json:"story"`
StoryVersion int `json:"storyVersion"`
Task int `json:"task"`
ToTask int `json:"toTask"`
ToStory int64 `json:"toStory"`
Title string `json:"title"`
Keywords string `json:"keywords"`
Severity int `json:"severity"`
Pri int `json:"pri"`
Type string `json:"type"`
Os string `json:"os"`
Browser string `json:"browser"`
Hardware string `json:"hardware"`
Found string `json:"found"`
Steps string `json:"steps"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Color string `json:"color"`
Confirmed int `json:"confirmed"`
ActivatedCount int `json:"activatedCount"`
ActivatedDate *helper.Iso8601Time `json:"activatedDate"`
FeedbackBy string `json:"feedbackBy"`
NotifyEmail string `json:"notifyEmail"`
OpenedById int64
OpenedByName string
OpenedDate *helper.Iso8601Time `json:"openedDate"`
OpenedBuild string `json:"openedBuild"`
AssignedToId int64
AssignedToName string
AssignedDate *helper.Iso8601Time `json:"assignedDate"`
Deadline string `json:"deadline"`
ResolvedById int64
Resolution string `json:"resolution"`
ResolvedBuild string `json:"resolvedBuild"`
ResolvedDate *helper.Iso8601Time `json:"resolvedDate"`
ClosedById int64
ClosedDate *helper.Iso8601Time `json:"closedDate"`
DuplicateBug int `json:"duplicateBug"`
LinkBug string `json:"linkBug"`
Feedback int `json:"feedback"`
Result int `json:"result"`
Repo int `json:"repo"`
Mr int `json:"mr"`
Entry string `json:"entry"`
NumOfLine string `json:"lines"`
V1 string `json:"v1"`
V2 string `json:"v2"`
RepoType string `json:"repoType"`
IssueKey string `json:"issueKey"`
Testtask int `json:"testtask"`
LastEditedById int64
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
Deleted bool `json:"deleted"`
PriOrder string `json:"priOrder"`
SeverityOrder int `json:"severityOrder"`
Needconfirm bool `json:"needconfirm"`
StatusName string `json:"statusName"`
ProductStatus string `json:"productStatus"`
Url string `json:"url"`
StdStatus string `json:"stdStatus" gorm:"type:varchar(20)"`
StdType string `json:"stdType" gorm:"type:varchar(20)"`
}
type ZentaoBugCommit ¶
type ZentaoBugCommit struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectType string `json:"objectType"`
ObjectID int `json:"objectID"`
Product int64 `json:"product"`
Project int64 `json:"project"`
Execution int `json:"execution"`
Actor string `json:"actor"`
Action string `json:"action"`
Date string `json:"date"`
Comment string `json:"comment"`
Extra string `json:"extra"`
Host string `json:"host"` //the host part of extra
RepoRevision string `json:"repoRevision"` // the repoRevisionJson part of extra
ActionRead string `json:"actionRead"`
Vision string `json:"vision"`
Efforted int `json:"efforted"`
ActionDesc string `json:"cctionDesc"`
}
func (ZentaoBugCommit) TableName ¶
func (ZentaoBugCommit) TableName() string
type ZentaoBugCommitsRes ¶
type ZentaoBugCommitsRes struct {
ID int `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectType string `json:"objectType"`
ObjectID int `json:"objectID"`
Product string `json:"product"`
Project int `json:"project"`
Execution int `json:"execution"`
Actor string `json:"actor"`
Action string `json:"action"`
Date string `json:"date"`
Comment string `json:"comment"`
Extra string `json:"extra"`
Read string `json:"read"`
Vision string `json:"vision"`
Efforted int `json:"efforted"`
Desc string `json:"desc"`
}
type ZentaoBugRepoCommit ¶
type ZentaoBugRepoCommit struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
Product int64 `json:"product"`
Project int64 `json:"project"`
IssueId string `gorm:"primaryKey;type:varchar(255)"` // the bug id
RepoUrl string `gorm:"primaryKey;type:varchar(255)"`
CommitSha string `gorm:"primaryKey;type:varchar(255)"`
}
func (ZentaoBugRepoCommit) TableName ¶
func (ZentaoBugRepoCommit) TableName() string
type ZentaoBugRepoCommitsRes ¶
type ZentaoBugRepoCommitsRes struct {
Title string `json:"title"`
Log struct {
Revision string `json:"revision"`
Committer string `json:"committer"`
Time string `json:"time"`
Comment string `json:"comment"`
Change struct {
TestYaml struct {
Action string `json:"action"`
Kind string `json:"kind"`
OldPath string `json:"oldPath"`
} `json:"/test.yaml"`
} `json:"change"`
Commit string `json:"commit"`
} `json:"log"`
Repo struct {
ID string `json:"id"`
Product string `json:"product"`
Projects string `json:"projects"`
Name string `json:"name"`
Path string `json:"path"`
Prefix string `json:"prefix"`
Encoding string `json:"encoding"`
Scm string `json:"SCM"`
Client string `json:"client"`
ServiceHost string `json:"serviceHost"`
ServiceProject string `json:"serviceProject"`
Commits string `json:"commits"`
Account string `json:"account"`
Password string `json:"password"`
Encrypt string `json:"encrypt"`
ACL any `json:"acl"`
Synced string `json:"synced"`
LastSync string `json:"lastSync"`
Desc string `json:"desc"`
Extra string `json:"extra"`
PreMerge string `json:"preMerge"`
Job string `json:"job"`
FileServerURL any `json:"fileServerUrl"`
FileServerAccount string `json:"fileServerAccount"`
FileServerPassword string `json:"fileServerPassword"`
Deleted string `json:"deleted"`
CodePath string `json:"codePath"`
GitService string `json:"gitService"`
Project string `json:"project"`
} `json:"repo"`
Path string `json:"path"`
Type string `json:"type"`
Changes struct {
TestYaml struct {
Action string `json:"action"`
Kind string `json:"kind"`
OldPath string `json:"oldPath"`
View string `json:"view"`
Diff string `json:"diff"`
} `json:"/test.yaml"`
} `json:"changes"`
RepoID string `json:"repoID"`
BranchID bool `json:"branchID"`
ObjectID string `json:"objectID"`
Revision string `json:"revision"`
ParentDir string `json:"parentDir"`
OldRevision string `json:"oldRevision"`
PreAndNext struct {
Pre string `json:"pre"`
Next string `json:"next"`
} `json:"preAndNext"`
Pager any `json:"pager"`
}
type ZentaoBugRes ¶
type ZentaoBugRes struct {
ID int64 `json:"id"`
Project int64 `json:"project"`
Product int64 `json:"product"`
Injection int `json:"injection"`
Identify int `json:"identify"`
Branch int `json:"branch"`
Module int `json:"module"`
Execution int64 `json:"execution"`
Plan int `json:"plan"`
Story int64 `json:"story"`
StoryVersion int `json:"storyVersion"`
Task int `json:"task"`
ToTask int `json:"toTask"`
ToStory int64 `json:"toStory"`
Title string `json:"title"`
Keywords string `json:"keywords"`
Severity int `json:"severity"`
Pri int `json:"pri"`
Type string `json:"type"`
Os string `json:"os"`
Browser string `json:"browser"`
Hardware string `json:"hardware"`
Found string `json:"found"`
Steps string `json:"steps"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Color string `json:"color"`
Confirmed int `json:"confirmed"`
ActivatedCount int `json:"activatedCount"`
ActivatedDate *helper.Iso8601Time `json:"activatedDate"`
FeedbackBy string `json:"feedbackBy"`
NotifyEmail string `json:"notifyEmail"`
OpenedBy *ZentaoAccount `json:"openedBy"`
OpenedDate *helper.Iso8601Time `json:"openedDate"`
OpenedBuild string `json:"openedBuild"`
AssignedTo *ZentaoAccount `json:"assignedTo"`
AssignedDate *helper.Iso8601Time `json:"assignedDate"`
Deadline string `json:"deadline"`
ResolvedBy *ZentaoAccount `json:"resolvedBy"`
Resolution string `json:"resolution"`
ResolvedBuild string `json:"resolvedBuild"`
ResolvedDate *helper.Iso8601Time `json:"resolvedDate"`
ClosedBy *ZentaoAccount `json:"closedBy"`
ClosedDate *helper.Iso8601Time `json:"closedDate"`
DuplicateBug int `json:"duplicateBug"`
LinkBug string `json:"linkBug"`
Feedback int `json:"feedback"`
Result int `json:"result"`
Repo int `json:"repo"`
Mr int `json:"mr"`
Entry string `json:"entry"`
NumOfLine string `json:"lines"`
V1 string `json:"v1"`
V2 string `json:"v2"`
RepoType string `json:"repoType"`
IssueKey string `json:"issueKey"`
Testtask int `json:"testtask"`
LastEditedBy *ZentaoAccount `json:"lastEditedBy"`
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
Deleted bool `json:"deleted"`
PriOrder string `json:"priOrder"`
SeverityOrder int `json:"severityOrder"`
Needconfirm bool `json:"needconfirm"`
StatusName string `json:"statusName"`
ProductStatus string `json:"productStatus"`
}
type ZentaoChangelog ¶
type ZentaoChangelog struct {
common.NoPKModel `json:"-"`
ConnectionId uint64 `json:"connectionId" mapstructure:"connectionId" gorm:"primaryKey;type:BIGINT NOT NULL"`
Id int64 `json:"id" mapstructure:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectId int `json:"objectId" mapstructure:"objectId" gorm:"index; NOT NULL"`
Execution int `json:"execution" mapstructure:"execution" `
Actor string `json:"actor" mapstructure:"actor" `
Action string `json:"action" mapstructure:"action"`
Extra string `json:"extra" mapstructure:"extra"`
ObjectType string `json:"objectType" mapstructure:"objectType"`
Project int `json:"project" mapstructure:"project"`
Product int `json:"product" mapstructure:"product"`
Vision string `json:"vision" mapstructure:"vision"`
Comment string `json:"comment" mapstructure:"comment"`
Efforted string `json:"efforted" mapstructure:"efforted"`
Date time.Time `json:"date" mapstructure:"date"`
Read string `json:"read" mapstructure:"read"`
}
func (ZentaoChangelog) TableName ¶
func (ZentaoChangelog) TableName() string
type ZentaoChangelogCom ¶
type ZentaoChangelogCom struct {
Changelog *ZentaoChangelog
ChangelogDetail *ZentaoChangelogDetail
}
type ZentaoChangelogDetail ¶
type ZentaoChangelogDetail struct {
common.NoPKModel `json:"-"`
ConnectionId uint64 `json:"connectionId" mapstructure:"connectionId" gorm:"primaryKey;type:BIGINT NOT NULL"`
Id int64 `json:"id" mapstructure:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ChangelogId int64 `json:"changelogId" mapstructure:"changelogId" gorm:"primaryKey;type:BIGINT NOT NULL"`
Field string `json:"field" mapstructure:"field"`
Old string `json:"old" mapstructure:"old"`
New string `json:"new" mapstructure:"new"`
Diff string `json:"diff" mapstructure:"diff"`
}
func (ZentaoChangelogDetail) TableName ¶
func (ZentaoChangelogDetail) TableName() string
type ZentaoConn ¶
type ZentaoConn struct {
helper.RestConnection `mapstructure:",squash"`
helper.BasicAuth `mapstructure:",squash"`
DbUrl string `mapstructure:"dbUrl" json:"dbUrl" gorm:"serializer:encdec"`
DbIdleConns int `json:"dbIdleConns" mapstructure:"dbIdleConns"`
DbLoggingLevel string `json:"dbLoggingLevel" mapstructure:"dbLoggingLevel"`
DbMaxConns int `json:"dbMaxConns" mapstructure:"dbMaxConns"`
}
ZentaoConn holds the essential information to connect to the Gitlab API
func (ZentaoConn) PrepareApiClient ¶
func (connection ZentaoConn) PrepareApiClient(apiClient apihelperabstract.ApiClientAbstract) errors.Error
PrepareApiClient fetches token from Zentao API for future requests
type ZentaoConnection ¶
type ZentaoConnection struct {
helper.BaseConnection `mapstructure:",squash"`
ZentaoConn `mapstructure:",squash"`
}
ZentaoConnection holds ZentaoConn plus ID/Name for database storage
func (ZentaoConnection) TableName ¶
func (ZentaoConnection) TableName() string
type ZentaoDepartment ¶
type ZentaoDepartment struct {
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int64 `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false" `
Name string `json:"name" gorm:"type:varchar(100);index"`
Parent int64 `json:"parent" gorm:"type:BIGINT NOT NULL"`
Path string `json:"path" gorm:"type:varchar(100)"`
Grade int `json:"grade"`
OrderIn int `json:"order"`
Position string `json:"position" gorm:"type:varchar(100)"`
DeptFunction string `json:"function" gorm:"type:varchar(100)"`
Manager string `json:"manager" gorm:"type:varchar(100)"`
ManagerName string `json:"managerName" gorm:"type:varchar(100)"`
common.NoPKModel
}
func (ZentaoDepartment) TableName ¶
func (ZentaoDepartment) TableName() string
type ZentaoExecution ¶
type ZentaoExecution struct {
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
Id int64 `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
Project int64 `json:"project"`
Model string `json:"model"`
Type string `json:"type"`
Lifetime string `json:"lifetime"`
Budget string `json:"budget"`
BudgetUnit string `json:"budgetUnit"`
Attribute string `json:"attribute"`
Percent int `json:"percent"`
Milestone string `json:"milestone"`
Output string `json:"output"`
Auth string `json:"auth"`
Parent int64 `json:"parent"`
Path string `json:"path"`
Grade int `json:"grade"`
Name string `json:"name"`
Code string `json:"code"`
PlanBegin *helper.Iso8601Time `json:"begin"`
PlanEnd *helper.Iso8601Time `json:"end"`
RealBegan *helper.Iso8601Time `json:"realBegan"`
RealEnd *helper.Iso8601Time `json:"realEnd"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Pri string `json:"pri"`
Description string `json:"desc"`
Version int `json:"version"`
ParentVersion int `json:"parentVersion"`
PlanDuration int `json:"planDuration"`
RealDuration int `json:"realDuration"`
OpenedById int64
OpenedDate *helper.Iso8601Time `json:"openedDate"`
OpenedVersion string `json:"openedVersion"`
LastEditedById int64
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ClosedById int64
ClosedDate *helper.Iso8601Time `json:"closedDate"`
CanceledById int64
CanceledDate *helper.Iso8601Time `json:"canceledDate"`
SuspendedDate *helper.Iso8601Time `json:"suspendedDate"`
POId int64
PMId int64
QDId int64
RDId int64
Team string `json:"team"`
Acl string `json:"acl"`
OrderIn int `json:"order"`
Vision string `json:"vision"`
DisplayCards int `json:"displayCards"`
FluidBoard string `json:"fluidBoard"`
Deleted bool `json:"deleted"`
TotalHours float64 `json:"totalHours"`
TotalEstimate float64 `json:"totalEstimate"`
TotalConsumed float64 `json:"totalConsumed"`
TotalLeft float64 `json:"totalLeft"`
ProjectId int64
Progress float64 `json:"progress"`
CaseReview bool `json:"caseReview"`
common.NoPKModel
}
func (ZentaoExecution) TableName ¶
func (ZentaoExecution) TableName() string
type ZentaoExecutionRes ¶
type ZentaoExecutionRes struct {
ID int64 `json:"id"`
Project int64 `json:"project"`
Model string `json:"model"`
Type string `json:"type"`
Lifetime string `json:"lifetime"`
Budget string `json:"budget"`
BudgetUnit string `json:"budgetUnit"`
Attribute string `json:"attribute"`
Percent int `json:"percent"`
Milestone string `json:"milestone"`
Output string `json:"output"`
Auth string `json:"auth"`
Parent int64 `json:"parent"`
Path string `json:"path"`
Grade int `json:"grade"`
Name string `json:"name"`
Code string `json:"code"`
PlanBegin *helper.Iso8601Time `json:"begin"`
PlanEnd *helper.Iso8601Time `json:"end"`
RealBegan *helper.Iso8601Time `json:"realBegan"`
RealEnd *helper.Iso8601Time `json:"realEnd"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Pri string `json:"pri"`
Description string `json:"desc"`
Version int `json:"version"`
ParentVersion int `json:"parentVersion"`
PlanDuration int `json:"planDuration"`
RealDuration int `json:"realDuration"`
OpenedBy *ZentaoAccount `json:"openedBy"`
OpenedDate *helper.Iso8601Time `json:"openedDate"`
OpenedVersion string `json:"openedVersion"`
LastEditedBy *ZentaoAccount `json:"lastEditedBy"`
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ClosedBy *ZentaoAccount `json:"closedBy"`
ClosedDate *helper.Iso8601Time `json:"closedDate"`
CanceledBy *ZentaoAccount `json:"canceledBy"`
CanceledDate *helper.Iso8601Time `json:"canceledDate"`
SuspendedDate *helper.Iso8601Time `json:"suspendedDate"`
PO *ZentaoAccount `json:"PO"`
PM *ZentaoAccount `json:"PM"`
QD *ZentaoAccount `json:"QD"`
RD *ZentaoAccount `json:"RD"`
Team string `json:"team"`
Acl string `json:"acl"`
Whitelist []*ZentaoAccount `json:"whitelist"`
OrderIn int `json:"order"`
Vision string `json:"vision"`
DisplayCards int `json:"displayCards"`
FluidBoard string `json:"fluidBoard"`
Deleted bool `json:"deleted"`
TotalHours float64 `json:"totalHours"`
TotalEstimate float64 `json:"totalEstimate"`
TotalConsumed float64 `json:"totalConsumed"`
TotalLeft float64 `json:"totalLeft"`
ProjectInfo struct {
ID int64 `json:"id"`
Project int64 `json:"project"`
Model string `json:"model"`
Type string `json:"type"`
Lifetime string `json:"lifetime"`
Budget string `json:"budget"`
BudgetUnit string `json:"budgetUnit"`
Attribute string `json:"attribute"`
Percent int `json:"percent"`
Milestone string `json:"milestone"`
Output string `json:"output"`
Auth string `json:"auth"`
Parent int64 `json:"parent"`
Path string `json:"path"`
Grade int `json:"grade"`
Name string `json:"name"`
Code string `json:"code"`
PlanBegin *helper.Iso8601Time `json:"begin"`
PlanEnd *helper.Iso8601Time `json:"end"`
RealBegan *helper.Iso8601Time `json:"realBegan"`
RealEnd *helper.Iso8601Time `json:"realEnd"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Pri string `json:"pri"`
Description string `json:"desc"`
Version int `json:"version"`
ParentVersion int `json:"parentVersion"`
PlanDuration int `json:"planDuration"`
RealDuration int `json:"realDuration"`
OpenedBy string `json:"openedBy"`
OpenedDate *helper.Iso8601Time `json:"openedDate"`
OpenedVersion string `json:"openedVersion"`
LastEditedBy string `json:"lastEditedBy"`
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ClosedBy string `json:"closedBy"`
ClosedDate *helper.Iso8601Time `json:"closedDate"`
CanceledBy string `json:"canceledBy"`
CanceledDate *helper.Iso8601Time `json:"canceledDate"`
SuspendedDate *helper.Iso8601Time `json:"suspendedDate"`
PO string `json:"PO"`
PM string `json:"PM"`
QD string `json:"QD"`
RD string `json:"RD"`
Team string `json:"team"`
Acl string `json:"acl"`
Whitelist string `json:"whitelist"`
OrderIn int `json:"order"`
Vision string `json:"vision"`
DisplayCards int `json:"displayCards"`
FluidBoard string `json:"fluidBoard"`
Deleted string `json:"deleted"`
} `json:"projectInfo"`
Progress float64 `json:"progress"`
TeamMembers []struct {
ID int64 `json:"id"`
Root int `json:"root"`
Type string `json:"type"`
Account string `json:"account"`
Role string `json:"role"`
Position string `json:"position"`
Limited string `json:"limited"`
Join string `json:"join"`
Hours int `json:"hours"`
Estimate string `json:"estimate"`
Consumed string `json:"consumed"`
Left string `json:"left"`
OrderIn int `json:"order"`
TotalHours float64 `json:"totalHours"`
UserID int64 `json:"userID"`
Realname string `json:"realname"`
} `json:"teamMembers"`
Products []struct {
ID int64 `json:"id"`
Name string `json:"name"`
Plans []interface{} `json:"plans"`
} `json:"products"`
CaseReview bool `json:"caseReview"`
}
type ZentaoProduct ¶
type ZentaoProduct struct {
common.NoPKModel `json:"-"`
ConnectionId uint64 `json:"connectionId" mapstructure:"connectionId" gorm:"primaryKey;type:BIGINT NOT NULL"`
Id int64 `json:"id" mapstructure:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
Program int `json:"program" mapstructure:"program"`
Name string `json:"name" mapstructure:"name"`
Code string `json:"code" mapstructure:"code"`
Bind string `json:"bind" mapstructure:"bind"`
Line int `json:"line" mapstructure:"line"`
Type string `json:"type" mapstructure:"type"`
ProductType string `json:"productType" mapstructure:"productType"`
Status string `json:"status" mapstructure:"status"`
SubStatus string `json:"subStatus" mapstructure:"subStatus"`
Description string `json:"desc" mapstructure:"desc"`
POId int64
QDId int64
RDId int64
Acl string `json:"acl" mapstructure:"acl"`
Reviewer string `json:"reviewer" mapstructure:"reviewer"`
CreatedById int64
CreatedDate *helper.Iso8601Time `json:"createdDate" mapstructure:"createdDate"`
CreatedVersion string `json:"createdVersion" mapstructure:"createdVersion"`
OrderIn int `json:"order" mapstructure:"order"`
Deleted string `json:"deleted" mapstructure:"deleted"`
Plans int `json:"plans" mapstructure:"plans"`
Releases int `json:"releases" mapstructure:"releases"`
Builds int `json:"builds" mapstructure:"builds"`
Cases int `json:"cases" mapstructure:"cases"`
Projects int `json:"projects" mapstructure:"projects"`
Executions int `json:"executions" mapstructure:"executions"`
Bugs int `json:"bugs" mapstructure:"bugs"`
Docs int `json:"docs" mapstructure:"docs"`
Progress float64 `json:"progress" mapstructure:"progress"`
CaseReview bool `json:"caseReview" mapstructure:"caseReview"`
ScopeConfigId uint64 `json:"scopeConfigId,omitempty" mapstructure:"scopeConfigId"`
}
func (ZentaoProduct) ScopeId ¶
func (p ZentaoProduct) ScopeId() string
func (ZentaoProduct) ScopeName ¶
func (p ZentaoProduct) ScopeName() string
func (ZentaoProduct) ScopeParams ¶
func (p ZentaoProduct) ScopeParams() interface{}
func (ZentaoProduct) TableName ¶
func (ZentaoProduct) TableName() string
type ZentaoProductRes ¶
type ZentaoProductRes struct {
ID int64 `json:"id" mapstructure:"id"`
Program int `json:"program" mapstructure:"program"`
Name string `json:"name" mapstructure:"name"`
Code string `json:"code" mapstructure:"code"`
Bind string `json:"bind" mapstructure:"bind"`
Line int `json:"line" mapstructure:"line"`
Type string `json:"type" mapstructure:"type"`
Status string `json:"status" mapstructure:"status"`
SubStatus string `json:"subStatus" mapstructure:"subStatus"`
Description string `json:"desc" mapstructure:"desc"`
PO *ZentaoAccount `json:"po" mapstructure:"po"`
QD *ZentaoAccount `json:"qd" mapstructure:"qd"`
RD *ZentaoAccount `json:"rd" mapstructure:"rd"`
Feedback interface{} `json:"feedback" mapstructure:"feedback"`
Acl string `json:"acl" mapstructure:"acl"`
Whitelist []interface{} `json:"whitelist" mapstructure:"whitelist"`
Reviewer string `json:"reviewer" mapstructure:"reviewer"`
CreatedBy *ZentaoAccount `json:"createdBy" mapstructure:"createdBy"`
CreatedDate *helper.Iso8601Time `json:"createdDate" mapstructure:"createdDate"`
CreatedVersion string `json:"createdVersion" mapstructure:"createdVersion"`
OrderIn int `json:"order" mapstructure:"order"`
Vision string `json:"vision" mapstructure:"vision"`
Deleted string `json:"deleted" mapstructure:"deleted"`
Stories struct {
Active int `json:"active" mapstructure:"active"`
Reviewing int `json:"reviewing" mapstructure:"reviewing"`
Draft int `json:"draft" mapstructure:"draft"`
Closed int `json:"closed" mapstructure:"closed"`
Changing int `json:"changing" mapstructure:"changing"`
// contains filtered or unexported fields
} `json:"stories"`
Plans int `json:"plans" mapstructure:"plans"`
Releases int `json:"releases" mapstructure:"releases"`
Builds int `json:"builds" mapstructure:"builds"`
Cases int `json:"cases" mapstructure:"cases"`
Projects int `json:"projects" mapstructure:"projects"`
Executions int `json:"executions" mapstructure:"executions"`
Bugs int `json:"bugs" mapstructure:"bugs"`
Docs int `json:"docs" mapstructure:"docs"`
Progress float64 `json:"progress" mapstructure:"progress"`
CaseReview bool `json:"caseReview" mapstructure:"caseReview"`
}
func (ZentaoProductRes) ConvertApiScope ¶
func (res ZentaoProductRes) ConvertApiScope() plugin.ToolLayerScope
type ZentaoProject ¶
type ZentaoProject struct {
common.NoPKModel `json:"-"`
ConnectionId uint64 `json:"connectionid" mapstructure:"connectionid" gorm:"primaryKey;type:BIGINT NOT NULL"`
Id int64 `json:"id" mapstructure:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
Project int64 `json:"project" mapstructure:"project"`
Model string `json:"model" mapstructure:"model"`
Type string `json:"type" mapstructure:"type"`
ProjectType string `json:"projectType" mapstructure:"projectType"`
Lifetime string `json:"lifetime" mapstructure:"lifetime"`
Budget string `json:"budget" mapstructure:"budget"`
BudgetUnit string `json:"budgetUnit" mapstructure:"budgetUnit"`
Attribute string `json:"attribute" mapstructure:"attribute"`
Percent int `json:"percent" mapstructure:"percent"`
Milestone string `json:"milestone" mapstructure:"milestone"`
Output string `json:"output" mapstructure:"output"`
Auth string `json:"auth" mapstructure:"auth"`
Parent int64 `json:"parent" mapstructure:"parent"`
Path string `json:"path" mapstructure:"path"`
Grade int `json:"grade" mapstructure:"grade"`
Name string `json:"name" mapstructure:"name"`
Code string `json:"code" mapstructure:"code"`
PlanBegin *helper.Iso8601Time `json:"begin" mapstructure:"begin"`
PlanEnd *helper.Iso8601Time `json:"end" mapstructure:"end"`
RealBegan *helper.Iso8601Time `json:"realBegan" mapstructure:"realBegan"`
RealEnd *helper.Iso8601Time `json:"realEnd" mapstructure:"realEnd"`
Days int `json:"days" mapstructure:"days"`
Status string `json:"status" mapstructure:"status"`
SubStatus string `json:"subStatus" mapstructure:"subStatus"`
Pri string `json:"pri" mapstructure:"pri"`
Description string `json:"desc" mapstructure:"desc"`
Version int `json:"version" mapstructure:"version"`
ParentVersion int `json:"parentVersion" mapstructure:"parentVersion"`
PlanDuration int `json:"planDuration" mapstructure:"planDuration"`
RealDuration int `json:"realDuration" mapstructure:"realDuration"`
//OpenedBy string `json:"openedBy" mapstructure:"openedBy"`
OpenedDate *helper.Iso8601Time `json:"openedDate" mapstructure:"openedDate"`
OpenedVersion string `json:"openedVersion" mapstructure:"openedVersion"`
//LastEditedBy string `json:"lastEditedBy" mapstructure:"lastEditedBy"`
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate" mapstructure:"lastEditedDate"`
ClosedBy string
ClosedByRes interface{} `json:"closedBy" mapstructure:"closedBy" gorm:"-"`
ClosedDate *helper.Iso8601Time `json:"closedDate" mapstructure:"closedDate"`
CanceledBy string
CanceledByRes interface{} `json:"canceledBy" mapstructure:"canceledBy" gorm:"-"`
CanceledDate *helper.Iso8601Time `json:"canceledDate" mapstructure:"canceledDate"`
SuspendedDate *helper.Iso8601Time `json:"suspendedDate" mapstructure:"suspendedDate"`
PO string `json:"po" mapstructure:"po"`
PM `json:"pm" mapstructure:"pm"`
QD string `json:"qd" mapstructure:"qd"`
RD string `json:"rd" mapstructure:"rd"`
Team string `json:"team" mapstructure:"team"`
Acl string `json:"acl" mapstructure:"acl"`
Whitelist `json:"whitelist" mapstructure:"" gorm:"-"`
OrderIn int `json:"order" mapstructure:"order"`
Vision string `json:"vision" mapstructure:"vision"`
DisplayCards int `json:"displayCards" mapstructure:"displayCards"`
FluidBoard string `json:"fluidBoard" mapstructure:"fluidBoard"`
Deleted bool `json:"deleted" mapstructure:"deleted"`
Delay int `json:"delay" mapstructure:"delay"`
Hours `json:"hours" mapstructure:"hours"`
TeamCount int `json:"teamCount" mapstructure:"teamCount"`
LeftTasks string `json:"leftTasks" mapstructure:"leftTasks"`
//TeamMembers []interface{} `json:"teamMembers" gorm:"-"`
TotalEstimate float64 `json:"totalEstimate" mapstructure:"totalEstimate"`
TotalConsumed float64 `json:"totalConsumed" mapstructure:"totalConsumed"`
TotalLeft float64 `json:"totalLeft" mapstructure:"totalLeft"`
Progress float64 `json:"progress" mapstructure:"progress"`
TotalReal int `json:"totalReal" mapstructure:"totalReal"`
ScopeConfigId uint64 `json:"scopeConfigId,omitempty" mapstructure:"scopeConfigId"`
}
func (ZentaoProject) ConvertApiScope ¶
func (p ZentaoProject) ConvertApiScope() plugin.ToolLayerScope
func (*ZentaoProject) ConvertFix ¶
func (p *ZentaoProject) ConvertFix()
func (ZentaoProject) ScopeId ¶
func (p ZentaoProject) ScopeId() string
func (ZentaoProject) ScopeName ¶
func (p ZentaoProject) ScopeName() string
func (ZentaoProject) ScopeParams ¶
func (p ZentaoProject) ScopeParams() interface{}
func (ZentaoProject) TableName ¶
func (ZentaoProject) TableName() string
type ZentaoRemoteDbAction ¶
type ZentaoRemoteDbAction struct {
Id int `gorm:"column:id"`
ObjectType string `gorm:"column:objectType"`
ObjectId int `gorm:"column:objectID"`
Product string `gorm:"column:product"`
Project int `gorm:"column:project"`
Execution int `gorm:"column:execution"`
Actor string `gorm:"column:actor"`
Action string `gorm:"column:action"`
Date time.Time `gorm:"column:date"`
Comment string `gorm:"column:comment"`
Extra string `gorm:"column:extra"`
Read string `gorm:"column:read"`
Vision string `gorm:"column:vision"`
Efforted string `gorm:"column:efforted"`
}
func (ZentaoRemoteDbAction) TableName ¶
func (ZentaoRemoteDbAction) TableName() string
type ZentaoRemoteDbActionHistory ¶
type ZentaoRemoteDbActionHistory struct {
ZentaoRemoteDbAction
ZentaoRemoteDbHistoryBase
ActionId int `gorm:"column:aid"`
HistoryId int `gorm:"column:hid"`
}
func (*ZentaoRemoteDbActionHistory) Convert ¶
func (ah *ZentaoRemoteDbActionHistory) Convert() *ZentaoChangelogCom
type ZentaoRemoteDbHistory ¶
type ZentaoRemoteDbHistory struct {
Id int `gorm:"column:id"`
Action int `gorm:"column:action"`
ZentaoRemoteDbHistoryBase
}
func (ZentaoRemoteDbHistory) TableName ¶
func (ZentaoRemoteDbHistory) TableName() string
type ZentaoResponse ¶
type ZentaoResponse struct {
Name string `json:"name"`
ID int64 `json:"id"`
ZentaoConnection
}
This object conforms to what the frontend currently expects.
type ZentaoScopeConfig ¶
type ZentaoScopeConfig struct {
common.ScopeConfig `mapstructure:",squash" json:",inline" gorm:"embedded"`
ConnectionId uint64 `mapstructure:"connectionId" json:"connectionId"`
Name string `gorm:"type:varchar(255);index:idx_name_tapd,unique" validate:"required" mapstructure:"name" json:"name"`
TypeMappings json.RawMessage `mapstructure:"typeMappings,omitempty" json:"typeMappings"`
BugStatusMappings json.RawMessage `mapstructure:"bugStatusMappings,omitempty" json:"bugStatusMappings"`
StoryStatusMappings json.RawMessage `mapstructure:"storyStatusMappings,omitempty" json:"storyStatusMappings"`
TaskStatusMappings json.RawMessage `mapstructure:"taskStatusMappings,omitempty" json:"taskStatusMappings"`
}
func (ZentaoScopeConfig) TableName ¶
func (t ZentaoScopeConfig) TableName() string
type ZentaoStory ¶
type ZentaoStory struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int64 `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false" `
Product int64 `json:"product"`
Branch int `json:"branch"`
Version int `json:"version"`
OrderIn int `json:"order"`
Vision string `json:"vision"`
Parent int64 `json:"parent"`
Module int `json:"module"`
Plan string `json:"plan"`
Source string `json:"source"`
SourceNote string `json:"sourceNote"`
FromBug int `json:"fromBug"`
Feedback int `json:"feedback"`
Title string `json:"title"`
Keywords string `json:"keywords"`
Type string `json:"type"`
Category string `json:"category"`
Pri int `json:"pri"`
Estimate float64 `json:"estimate"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Color string `json:"color"`
Stage string `json:"stage"`
//Mailto []interface{} `json:"mailto"`
Lib int `json:"lib"`
FromStory int64 `json:"fromStory"`
FromVersion int `json:"fromVersion"`
OpenedById int64
OpenedByName string
OpenedDate *helper.Iso8601Time `json:"openedDate"`
AssignedToId int64
AssignedToName string
AssignedDate *helper.Iso8601Time `json:"assignedDate"`
ApprovedDate *helper.Iso8601Time `json:"approvedDate"`
LastEditedId int64
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ChangedDate *helper.Iso8601Time `json:"changedDate"`
ReviewedById int64 `json:"reviewedBy"`
ReviewedDate *helper.Iso8601Time `json:"reviewedDate"`
ClosedId int64
ClosedDate *helper.Iso8601Time `json:"closedDate"`
ClosedReason string `json:"closedReason"`
ActivatedDate *helper.Iso8601Time `json:"activatedDate"`
ToBug int `json:"toBug"`
ChildStories string `json:"childStories"`
LinkStories string `json:"linkStories"`
LinkRequirements string `json:"linkRequirements"`
DuplicateStory int64 `json:"duplicateStory"`
StoryChanged string `json:"storyChanged"`
FeedbackBy string `json:"feedbackBy"`
NotifyEmail string `json:"notifyEmail"`
URChanged string `json:"URChanged"`
Deleted bool `json:"deleted"`
PriOrder string `json:"priOrder"`
PlanTitle string `json:"planTitle"`
Url string `json:"url"`
StdStatus string `json:"stdStatus" gorm:"type:varchar(20)"`
StdType string `json:"stdType" gorm:"type:varchar(20)"`
}
func (ZentaoStory) TableName ¶
func (ZentaoStory) TableName() string
type ZentaoStoryCommit ¶
type ZentaoStoryCommit struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectType string `json:"objectType"`
ObjectID int `json:"objectID"`
Product int64 `json:"product"`
Project int64 `json:"project"`
Execution int `json:"execution"`
Actor string `json:"actor"`
Action string `json:"action"`
Date string `json:"date"`
Comment string `json:"comment"`
Extra string `json:"extra"`
Host string `json:"host"` //the host part of extra
RepoRevision string `json:"repoRevision"` // the repoRevisionJson part of extra
ActionRead string `json:"actionRead"`
Vision string `json:"vision"`
Efforted int `json:"efforted"`
ActionDesc string `json:"cctionDesc"`
}
func (ZentaoStoryCommit) TableName ¶
func (ZentaoStoryCommit) TableName() string
type ZentaoStoryCommitsRes ¶
type ZentaoStoryCommitsRes struct {
ID int `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectType string `json:"objectType"`
ObjectID int `json:"objectID"`
Product string `json:"product"`
Project int `json:"project"`
Execution int `json:"execution"`
Actor string `json:"actor"`
Action string `json:"action"`
Date string `json:"date"`
Comment string `json:"comment"`
Extra string `json:"extra"`
Read string `json:"read"`
Vision string `json:"vision"`
Efforted int `json:"efforted"`
Desc string `json:"desc"`
}
type ZentaoStoryRepoCommit ¶
type ZentaoStoryRepoCommit struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
Product int64 `json:"product"`
Project int64 `json:"project"`
IssueId string `gorm:"primaryKey;type:varchar(255)"` // the story id
RepoUrl string `gorm:"primaryKey;type:varchar(255)"`
CommitSha string `gorm:"primaryKey;type:varchar(255)"`
}
func (ZentaoStoryRepoCommit) TableName ¶
func (ZentaoStoryRepoCommit) TableName() string
type ZentaoStoryRepoCommitsRes ¶
type ZentaoStoryRepoCommitsRes struct {
Title string `json:"title"`
Log struct {
Revision string `json:"revision"`
Committer string `json:"committer"`
Time string `json:"time"`
Comment string `json:"comment"`
Change struct {
TestYaml struct {
Action string `json:"action"`
Kind string `json:"kind"`
OldPath string `json:"oldPath"`
} `json:"/test.yaml"`
} `json:"change"`
Commit string `json:"commit"`
} `json:"log"`
Repo struct {
ID string `json:"id"`
Product string `json:"product"`
Projects string `json:"projects"`
Name string `json:"name"`
Path string `json:"path"`
Prefix string `json:"prefix"`
Encoding string `json:"encoding"`
Scm string `json:"SCM"`
Client string `json:"client"`
ServiceHost string `json:"serviceHost"`
ServiceProject string `json:"serviceProject"`
Commits string `json:"commits"`
Account string `json:"account"`
Password string `json:"password"`
Encrypt string `json:"encrypt"`
ACL any `json:"acl"`
Synced string `json:"synced"`
LastSync string `json:"lastSync"`
Desc string `json:"desc"`
Extra string `json:"extra"`
PreMerge string `json:"preMerge"`
Job string `json:"job"`
FileServerURL any `json:"fileServerUrl"`
FileServerAccount string `json:"fileServerAccount"`
FileServerPassword string `json:"fileServerPassword"`
Deleted string `json:"deleted"`
CodePath string `json:"codePath"`
GitService string `json:"gitService"`
Project string `json:"project"`
} `json:"repo"`
Path string `json:"path"`
Type string `json:"type"`
Changes struct {
TestYaml struct {
Action string `json:"action"`
Kind string `json:"kind"`
OldPath string `json:"oldPath"`
View string `json:"view"`
Diff string `json:"diff"`
} `json:"/test.yaml"`
} `json:"changes"`
RepoID string `json:"repoID"`
BranchID bool `json:"branchID"`
ObjectID string `json:"objectID"`
Revision string `json:"revision"`
ParentDir string `json:"parentDir"`
OldRevision string `json:"oldRevision"`
PreAndNext struct {
Pre string `json:"pre"`
Next string `json:"next"`
} `json:"preAndNext"`
Pager any `json:"pager"`
}
type ZentaoStoryRes ¶
type ZentaoStoryRes struct {
ID int64 `json:"id"`
Vision string `json:"vision"`
Parent int64 `json:"parent"`
Product int64 `json:"product"`
Branch int `json:"branch"`
Module int `json:"module"`
Plan string `json:"plan"`
Source string `json:"source"`
SourceNote string `json:"sourceNote"`
FromBug int `json:"fromBug"`
Feedback int `json:"feedback"`
Title string `json:"title"`
Keywords string `json:"keywords"`
Type string `json:"type"`
Category string `json:"category"`
Pri int `json:"pri"`
Estimate float64 `json:"estimate"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Color string `json:"color"`
Stage string `json:"stage"`
Mailto []interface{} `json:"mailto"`
Lib int `json:"lib"`
FromStory int64 `json:"fromStory"`
FromVersion int `json:"fromVersion"`
OpenedBy *ZentaoAccount `json:"openedBy"`
OpenedDate *helper.Iso8601Time `json:"openedDate"`
AssignedTo *ZentaoAccount `json:"assignedTo"`
AssignedDate *helper.Iso8601Time `json:"assignedDate"`
ApprovedDate *helper.Iso8601Time `json:"approvedDate"`
LastEditedBy *ZentaoAccount `json:"lastEditedBy"`
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ChangedBy string `json:"changedBy"`
ChangedDate *helper.Iso8601Time `json:"changedDate"`
ReviewedBy *ZentaoAccount `json:"reviewedBy"`
ReviewedDate *helper.Iso8601Time `json:"reviewedDate"`
ClosedBy *ZentaoAccount `json:"closedBy"`
ClosedDate *helper.Iso8601Time `json:"closedDate"`
ClosedReason string `json:"closedReason"`
ActivatedDate *helper.Iso8601Time `json:"activatedDate"`
ToBug int `json:"toBug"`
ChildStories string `json:"childStories"`
LinkStories string `json:"linkStories"`
LinkRequirements string `json:"linkRequirements"`
DuplicateStory int64 `json:"duplicateStory"`
Version int `json:"version"`
StoryChanged string `json:"storyChanged"`
FeedbackBy string `json:"feedbackBy"`
NotifyEmail string `json:"notifyEmail"`
URChanged string `json:"URChanged"`
Deleted bool `json:"deleted"`
PriOrder string `json:"priOrder"`
PlanTitle string `json:"planTitle"`
ProductStatus string `json:"productStatus"`
}
type ZentaoTask ¶
type ZentaoTask struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int64 `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
Project int64 `json:"project"`
Parent int64 `json:"parent"`
Execution int64 `json:"execution"`
Module int `json:"module"`
Design int `json:"design"`
Story int64 `json:"story"`
StoryVersion int `json:"storyVersion"`
DesignVersion int `json:"designVersion"`
FromBug int `json:"fromBug"`
Feedback int `json:"feedback"`
FromIssue int `json:"fromIssue"`
Name string `json:"name"`
Type string `json:"type"`
Mode string `json:"mode"`
Pri int `json:"pri"`
Estimate float64 `json:"estimate"`
Consumed float64 `json:"consumed"`
Left float64 `json:"left" gorm:"column:db_left"`
Deadline string `json:"deadline"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Color string `json:"color"`
//Mailto interface{} `json:"mailto"`
Description string `json:"desc"`
Version int `json:"version"`
OpenedById int64
OpenedByName string
OpenedDate *helper.Iso8601Time `json:"openedDate"`
AssignedToId int64
AssignedToName string
AssignedDate *helper.Iso8601Time `json:"assignedDate"`
EstStarted string `json:"estStarted"`
RealStarted *helper.Iso8601Time `json:"realStarted"`
FinishedId int64
FinishedDate *helper.Iso8601Time `json:"finishedDate"`
FinishedList string `json:"finishedList"`
CanceledId int64
CanceledDate *helper.Iso8601Time `json:"canceledDate"`
ClosedById int64
ClosedDate *helper.Iso8601Time `json:"closedDate"`
PlanDuration int `json:"planDuration"`
RealDuration int `json:"realDuration"`
ClosedReason string `json:"closedReason"`
LastEditedId int64
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ActivatedDate *helper.Iso8601Time `json:"activatedDate"`
OrderIn int `json:"order"`
Repo int `json:"repo"`
Mr int `json:"mr"`
Entry string `json:"entry"`
NumOfLine string `json:"lines"`
V1 string `json:"v1"`
V2 string `json:"v2"`
Deleted bool `json:"deleted"`
Vision string `json:"vision"`
StoryID int64 `json:"storyID"`
StoryTitle string `json:"storyTitle"`
Branch int `json:"branch"`
LatestStoryVersion int `json:"latestStoryVersion"`
StoryStatus string `json:"storyStatus"`
AssignedToRealName string `json:"assignedToRealName"`
PriOrder string `json:"priOrder"`
NeedConfirm bool `json:"needConfirm"`
Progress float64 `json:"progress"`
Url string `json:"url"`
StdStatus string `json:"stdStatus" gorm:"type:varchar(20)"`
StdType string `json:"stdType" gorm:"type:varchar(20)"`
}
func (ZentaoTask) TableName ¶
func (ZentaoTask) TableName() string
type ZentaoTaskCommit ¶
type ZentaoTaskCommit struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
ID int `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectType string `json:"objectType"`
ObjectID int `json:"objectID"`
Product int64 `json:"product"`
Project int64 `json:"project"`
Execution int `json:"execution"`
Actor string `json:"actor"`
Action string `json:"action"`
Date string `json:"date"`
Comment string `json:"comment"`
Extra string `json:"extra"`
Host string `json:"host"` //the host part of extra
RepoRevision string `json:"repoRevision"` // the repoRevisionJson part of extra
ActionRead string `json:"actionRead"`
Vision string `json:"vision"`
Efforted int `json:"efforted"`
ActionDesc string `json:"cctionDesc"`
}
func (ZentaoTaskCommit) TableName ¶
func (ZentaoTaskCommit) TableName() string
type ZentaoTaskCommitsRes ¶
type ZentaoTaskCommitsRes struct {
ID int `json:"id" gorm:"primaryKey;type:BIGINT NOT NULL;autoIncrement:false"`
ObjectType string `json:"objectType"`
ObjectID int `json:"objectID"`
Product string `json:"product"`
Project int `json:"project"`
Execution int `json:"execution"`
Actor string `json:"actor"`
Action string `json:"action"`
Date string `json:"date"`
Comment string `json:"comment"`
Extra string `json:"extra"`
Read string `json:"read"`
Vision string `json:"vision"`
Efforted int `json:"efforted"`
Desc string `json:"desc"`
}
type ZentaoTaskRepoCommit ¶
type ZentaoTaskRepoCommit struct {
common.NoPKModel
ConnectionId uint64 `gorm:"primaryKey;type:BIGINT NOT NULL"`
Product int64 `json:"product"`
Project int64 `json:"project"`
IssueId string `gorm:"primaryKey;type:varchar(255)"` // the task id
RepoUrl string `gorm:"primaryKey;type:varchar(255)"`
CommitSha string `gorm:"primaryKey;type:varchar(255)"`
}
func (ZentaoTaskRepoCommit) TableName ¶
func (ZentaoTaskRepoCommit) TableName() string
type ZentaoTaskRepoCommitsRes ¶
type ZentaoTaskRepoCommitsRes struct {
Title string `json:"title"`
Log struct {
Revision string `json:"revision"`
Committer string `json:"committer"`
Time string `json:"time"`
Comment string `json:"comment"`
Change struct {
TestYaml struct {
Action string `json:"action"`
Kind string `json:"kind"`
OldPath string `json:"oldPath"`
} `json:"/test.yaml"`
} `json:"change"`
Commit string `json:"commit"`
} `json:"log"`
Repo struct {
ID string `json:"id"`
Product string `json:"product"`
Projects string `json:"projects"`
Name string `json:"name"`
Path string `json:"path"`
Prefix string `json:"prefix"`
Encoding string `json:"encoding"`
Scm string `json:"SCM"`
Client string `json:"client"`
ServiceHost string `json:"serviceHost"`
ServiceProject string `json:"serviceProject"`
Commits string `json:"commits"`
Account string `json:"account"`
Password string `json:"password"`
Encrypt string `json:"encrypt"`
ACL any `json:"acl"`
Synced string `json:"synced"`
LastSync string `json:"lastSync"`
Desc string `json:"desc"`
Extra string `json:"extra"`
PreMerge string `json:"preMerge"`
Job string `json:"job"`
FileServerURL any `json:"fileServerUrl"`
FileServerAccount string `json:"fileServerAccount"`
FileServerPassword string `json:"fileServerPassword"`
Deleted string `json:"deleted"`
CodePath string `json:"codePath"`
GitService string `json:"gitService"`
Project string `json:"project"`
} `json:"repo"`
Path string `json:"path"`
Type string `json:"type"`
Changes struct {
TestYaml struct {
Action string `json:"action"`
Kind string `json:"kind"`
OldPath string `json:"oldPath"`
View string `json:"view"`
Diff string `json:"diff"`
} `json:"/test.yaml"`
} `json:"changes"`
RepoID string `json:"repoID"`
BranchID bool `json:"branchID"`
ObjectID string `json:"objectID"`
Revision string `json:"revision"`
ParentDir string `json:"parentDir"`
OldRevision string `json:"oldRevision"`
PreAndNext struct {
Pre string `json:"pre"`
Next string `json:"next"`
} `json:"preAndNext"`
Pager any `json:"pager"`
}
type ZentaoTaskRes ¶
type ZentaoTaskRes struct {
Id int64 `json:"id"`
Project int64 `json:"project"`
Parent int64 `json:"parent"`
Execution int64 `json:"execution"`
Module int `json:"module"`
Design int `json:"design"`
Story int64 `json:"story"`
StoryVersion int `json:"storyVersion"`
DesignVersion int `json:"designVersion"`
FromBug int `json:"fromBug"`
Feedback int `json:"feedback"`
FromIssue int `json:"fromIssue"`
Name string `json:"name"`
Type string `json:"type"`
Mode string `json:"mode"`
Pri int `json:"pri"`
Estimate float64 `json:"estimate"`
Consumed float64 `json:"consumed"`
Left float64 `json:"left"`
Deadline string `json:"deadline"`
Status string `json:"status"`
SubStatus string `json:"subStatus"`
Color string `json:"color"`
Mailto []*ZentaoAccount `json:"mailto"`
Description string `json:"desc"`
Version int `json:"version"`
OpenedBy *ZentaoAccount `json:"openedBy"`
OpenedDate *helper.Iso8601Time `json:"openedDate"`
AssignedTo *ZentaoAccount `json:"assignedTo"`
AssignedDate *helper.Iso8601Time `json:"assignedDate"`
EstStarted string `json:"estStarted"`
RealStarted *helper.Iso8601Time `json:"realStarted"`
FinishedBy *ZentaoAccount `json:"finishedBy"`
FinishedDate *helper.Iso8601Time `json:"finishedDate"`
FinishedList string `json:"finishedList"`
CanceledBy *ZentaoAccount `json:"canceledBy"`
CanceledDate *helper.Iso8601Time `json:"canceledDate"`
ClosedBy *ZentaoAccount `json:"closedBy"`
ClosedDate *helper.Iso8601Time `json:"closedDate"`
PlanDuration int `json:"planDuration"`
RealDuration int `json:"realDuration"`
ClosedReason string `json:"closedReason"`
LastEditedBy *ZentaoAccount `json:"lastEditedBy"`
LastEditedDate *helper.Iso8601Time `json:"lastEditedDate"`
ActivatedDate *helper.Iso8601Time `json:"activatedDate"`
OrderIn int `json:"order"`
Repo int `json:"repo"`
Mr int `json:"mr"`
Entry string `json:"entry"`
NumOfLine string `json:"lines"`
V1 string `json:"v1"`
V2 string `json:"v2"`
Deleted bool `json:"deleted"`
Vision string `json:"vision"`
StoryID int64 `json:"storyID"`
StoryTitle string `json:"storyTitle"`
Branch interface {
} `json:"branch"`
LatestStoryVersion interface {
} `json:"latestStoryVersion"`
StoryStatus interface {
} `json:"storyStatus"`
AssignedToRealName string `json:"assignedToRealName"`
PriOrder string `json:"priOrder"`
Delay int `json:"delay"`
NeedConfirm bool `json:"needConfirm"`
Progress float64 `json:"progress"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.